%%
clc
clear all
fprintf('Izraun najmanjega tornega kolinika, da bo vijak e samozaporen [M24]\n\n')
%Izraun koeficienta trenja
%Predpostavka je, da je koeficient trenja med navoji enak koef. trenja med
%glavo in vijaencem
format long
%Vhodni podatki
%M24
d2_24=22.05; %[mm]
beta=60;%[] lastnost metrinega navoja
P_24=3;%[mm] korak navoja M24
fi_24=atand(P_24/(pi*d2_24));
%Navoj je samozaporen takrat, ko je fi manji od ro1
%raunamo najmanji koeficient, pri katerem bo fi=ro1
koeftr=(P_24*cos(beta/2)/(pi*d2_24));
fprintf('Kot vzpona vijanice M24 meri %.2f\n',fi_24)
fprintf('Najmanji koeficient trenja med navoji, ki je na meji samozapornosti je %.4f (e je koeficient manji bo vijak nesamozaporen)\n\n\n',koeftr)
%%
fprintf('Obdelava merjenih podatkov za M16 - LV\n')
fprintf('Izris grafa: \n\n\n')
%Stolpci na vhodu si sledijo:
%40 Nm
%60 Nm
%80 Nm
%100 Nm
%120 Nm
%Vrednosti meritev so v V (voltih)
%1V = 10 kN
moment=40:20:120;
vhod1=xlsread('podatki1.xlsx');
for i=1:length(vhod1)
   povp1(i,:)=mean(vhod1(i,:)); 
end
vhod2=xlsread('podatki2.xlsx');
for i=1:length(vhod2)
   povp2(i,:)=mean(vhod2(i,:)); 
end
sila1=povp1*10; % pretvorba iz napetosti v silo [kN]
sila2=povp2*10;

figure
hold on
grid on
plot(moment,sila1,'ro','LineWidth',2)
plot(moment,sila2,'ko','LineWidth',2)
xlabel ('Moment [Nm]')
ylabel ('Sila [kN]')
title ('Meritev sile v vijaku glede na aplicirani moment preko kljua')
for i=1:length(sila1)
    fprintf('Meritev pri suhem trenju za moment %.1f Nm je %.2f kN \n',moment(i),sila1(i))
end
fprintf('\n')
for i=1:length(sila2)
    fprintf('Meritev pri mazanem trenju za moment %.1f Nm je %.2f kN \n',moment(i),sila2(i))
end

%%
fprintf('\n\nTorni koeficienti\n')
%M16
% M_a=40000; %[N*mm]
% F_vm=4600;% [N]
P=2;%[mm] korak navoja M16
d2=14.70;%[mm] srednji premer vijaka
fi=atand(P/(pi*d2));
dw=24; %zev kljua [mm]
dl=17; %premer luknje (predpostavljen) [mm]
dk=(dl+dw)/2;
fprintf('Kot vzpona vijanice za M16 je %.2f\n',fi)
%Glede na meritve koeficienta trenja lahko doloim torni kot
for i=1:length(moment)
   %raunaj za mazan (podatki 1) 
    syms mi1
    eqn1=((dk*tand(fi))/cosd(30))*mi1^2+((((-2*moment(i)*tand(fi))/sila1(i))-d2-dk*cosd(30))/cosd(30))*mi1+(2*moment(i))/sila1(i)-d2*tand(fi)==0;
    rezultat1=solve(eqn1,mi1);%rei enabo
    doublerez1=double(rezultat1);%iz simbola v double
    ni1(i)=min(doublerez1);%izbere primerno reitev
end
koef1=mean(ni1);
fprintf('Povpreen torni koeficient za podatke tevilka 1 (suho trenje) je %.4f \n',koef1)
for i=1:length(moment)
   %raunaj za mazan (podatki 1) 
    syms mi2
    eqn2=((dk*tand(fi))/cosd(30))*mi2^2+((((-2*moment(i)*tand(fi))/sila2(i))-d2-dk*cosd(30))/cosd(30))*mi2+(2*moment(i))/sila2(i)-d2*tand(fi)==0;
    rezultat2=solve(eqn2,mi2);%rei enabo
    doublerez2=double(rezultat2);%iz simbola v double
    ni2(i)=min(doublerez2);%izbere primerno reitev
end
koef2=mean(ni2);

F1=polyfit(moment',sila1,1);%aproksimacijski polinom za podatke 1
F2=polyfit(moment',sila2,1);%aproksimacijski polinom za podatke 2
X=linspace(min(moment),max(moment),500);%vektor abscisnih vrednosti za izris aproksimacijskih polinomov

plot(X,polyval(F1,X),'c','LineWidth',2)
plot(X,polyval(F2,X),'m','LineWidth',2)

fprintf('Povpreen torni koeficient za podatke tevilka 2 (mazano trenje) je %.4f \n\n',koef2)
fprintf('Glede na aproksimacijsko krivuljo je povpreen globalni suh torni koeficient %.4f\n',F1(1))
fprintf('Glede na aproksimacijsko krivuljo je povpreen globalni mazan torni koeficient %.4f\n\n',F2(1))
fprintf('Literatura (predloga LV) predlaga suh torni koeficient za cinkan vijak ter rno podlago (povpreje): 0,10 do 0,18\n')
fprintf('Literatura (predloga LV) predlaga mazan torni koeficient za cinkan vijak ter rno podlago (povpreje): 0,11 do 0,19\n\n')
fprintf('VDI 2230 predpostavlja za suho trenje torni koeficient >0,20\n')
fprintf('VDI 2230 za mazano trenje predpostavlja torni koeficient 0,08 do 0,16\n')
